<?php declare(strict_types=1);

namespace App\Form;

use App\Entity\ItemExtra;
use App\Entity\MenuItem;
use App\Entity\OrderItem;
use Override;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

// ...
class OrderItemType extends AbstractType
{
    /**
     * @param array{menuItem: MenuItem} $options
     */
    #[Override]
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder->add(
            'extras',
            EntityType::class,
            [
                'class' => ItemExtra::class,
                'choices' => $options['menuItem']->getItemExtras(),
                'choice_label' => 'name', // Change this for the field you want to display
                'multiple' => true,
                'expanded' => true,
            ],
        );
        $builder->add('customextra', TextType::class, [
            'label' => 'Not yet know extras, seperated by comma',
            'mapped' => false,
            'attr' => ['datalist' => 'item-extra-list'],
        ]);
    }

    #[Override]
    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => OrderItem::class,
        ]);
        $resolver->setRequired('menuItem');
        $resolver->setAllowedTypes('menuItem', MenuItem::class);
    }
}
